/*
 * Copyright (c) 2010 by Intevation GmbH
 *
 * This program is free software under the LGPL (>=v2.1)
 * Read the file LGPL.txt coming with the software for details
 * or visit http://www.gnu.org/licenses/ if it does not exist.
 */

package de.intevation.gnv.artifactdatabase.objects.map;

import java.util.Collection;

/**
 * This interface defines some basic methods to provide information about a map
 * service.
 *
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 */
public interface MapService {

    /**
     * Retrieves the id of a map service.
     *
     * @return the id of a map service.
     */
    String getID();


    /**
     * Retrieves the URL of a map service.
     *
     * @return the URL of a map service.
     */
    String getURL();


    /**
     * Retrieves the type of a map service.
     *
     * @return the type of a map service.
     */
    String getType();

    /**
     * Retrieves the layers served by a map service.
     *
     * @return the layers served by a map service.
     */
    Collection<Layer> getLayer();
    
    /**
     * Retrieves the bboxvalue served by a map service.
     * @return the bboxvalue
     */
    String getBBoxValue ();
    
    /**
     * Returns the Time until the Service will provide the Data.
     * @return the Time until the Service will provide the Data.
     */
    String getTtl();
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
